function nefgui(action, p1);   
  
%NEFGUI GUI-Tool to manage Nefcon settings.  
%       NEFGUI is the main control window to all NEFCON settings.
%       
%       NEFGUI;
%
% See also NEFGUI_O, NEFGUI_E, NEFGUI_I and NEFCON.  
   
% Author: Andreas Nuernberger, TU Braunschweig, August 1996; a.nuernberger@tu-bs.de
%         contact: Ludger Merz, DASA-Airbus GmbH, Hamburg; ludger.merz@airbus.de
  

% Globals:  described in nefmat  
global NEFCON_PROT NEFCON_STAT NEFCON_UIH NEFCON_RULE NEFCON_OPT NEFCON_IFM NEFCON_EFM NEFCON_EFMN  
global NEFCON_RATE NEFCON_FERR NEFCON_FIS NEFCON_NUMIN  
global NEFCON_RBT NEFCON_RBND NEFCON_RBT1 NEFCON_RBND1 NEFCON_OBT NEFCON_OBND   
  
global NEFCON_CYC  
global NEFCON_STOP  
global NEFCON_NOISE 
  
%true if forward or backward button is pressed 
global NEFCON_BTN 
 
%actual cycle  
global NEFCON_ACTCYC  
 
global NEFCON_SYSNAME 
  
global NEFCON_SYS  
 
global NEFCON_SHANDLE  
  
%settings of last simulation (for continue) 
global NEFCON_X0 NEFCON_TIME NEFCON_YS 
 
global NEFCON_STATEX 
 
%actual input/output intervall and gain information   
global NEFCON_INT NEFCON_GAIN 

NEFCON_UIH = findobj('Tag', 'NEFCONGUI');  
  
if nargin < 1  
    if NEFCON_UIH == []  
        action = 'initialize';  
    else  
        action = '';  
    end;  
end;  
% Information for all objects  
statdColor=220/255*[1 1 1];  
stateColor=[1 1 1];  
yellow = [1 1 0]; 
bckfrmColor=230/255*[1 1 1];  
frmColor=192/255*[1 1 1];  
bckColor=230/255*[1 1 1];  
btnColor=192/255*[1 1 1];  
popupColor=192/255*[1 1 1];  
editColor=255/255*[1 1 1];  
blockColor=[0.7 0.7 1];  
lineColor=[0 0 0];  
 
if strcmp(computer,'PCWIN') 
    % used for buttons (always grey) 
    blockColor = btnColor; 
end 
 
%create controls  
if strcmp(action, 'initialize') & NEFCON_UIH == [],  
    nefdef; 
    border=6;  
    spacing=8;  
  
    %Calculate Windowsize  
    figPos=get(0,'DefaultFigurePosition');  
    figPos(4) = 0.63 * figPos(3);  
    maxRight=figPos(3);  
    maxTop=figPos(4);  
  
    % uicontrol sizes  
%    btnWid  = 110;  
%    btnHt   = 23;  
    btnWid = maxRight/6;  
    btnHt  = maxRight/25;  
  
    % calculate normalized units for resizeable window  
    Nborder = border/maxRight;  
    Nspacing= spacing/maxRight;  
    NbtnWid = btnWid/maxRight;  
    NbtnHt  = btnHt/maxTop;  
  
    % userdata  
    localdata = [];  
  
    % open new window  
    h = figure( ...  
        'Name','Nefcon Control', ...  
        'NumberTitle','off', ...  
    	'Color',bckColor, ...  
	    'Visible','on', ...  
	    'UserData',localdata, ...  
    	'Units','pixels', ...  
	    'DefaultAxesXColor','black', ...  
    	'DefaultAxesYColor','black', ...  
    	'MenuBar','none', ...  
	    'Resize','on', ...  
	    'Position',figPos, ...  
    	'Nextplot','new', ...  
    	'Tag','NEFCONGUI' ...  
	    );  
    figPos=get(h,'position');  
  
    % create axes for line drawing etc.  
    hax=axes('Position', [0,0,1,1], ...  
        'Units', 'normalized', ...  
        'XLim', [0 1], 'yLim', [0 1], ...  
        'Visible','off');  
  
% ---------------------------------------------  
% create menus  
% ---------------------------------------------  
    labelStr=menulabel('&File ');  
    fileHndl=uimenu(h,'Label',labelStr);  
    [labelStr,accelStr]=menulabel('&New System ^n');  
    uimenu(fileHndl,'Label',labelStr, ...  
            'Separator','off', ...  
	    'Accelerator',accelStr, ...  
        'Interruptible', 'no', ...  
	    'Callback','nefgui (''new'')');  
    [labelStr,accelStr]=menulabel('&Save settings ^s');  
    uimenu(fileHndl,'Label',labelStr, ...  
            'Separator','off', ...  
	    'Accelerator',accelStr, ...  
        'Interruptible', 'no', ...  
	    'Callback','nefgui (''save'')');  
    [labelStr,accelStr]=menulabel('&Load settings ^l');  
    uimenu(fileHndl,'Label',labelStr, ...  
            'Separator','off', ...  
	    'Accelerator',accelStr, ...  
        'Interruptible', 'no', ...  
	    'Callback','nefgui (''load'')');  
    [labelStr,accelStr]=menulabel('Save &fismatrix ^f');  
    uimenu(fileHndl,'Label',labelStr, ...  
            'Separator','on', ...  
	    'Accelerator',accelStr, ...  
        'Interruptible', 'no', ...  
	    'Callback','nefgui (''savef'')');  
    [labelStr,accelStr]=menulabel('Load fis&matrix ^m');  
    uimenu(fileHndl,'Label',labelStr, ...  
            'Separator','off', ...  
	    'Accelerator',accelStr, ...  
        'Interruptible', 'no', ...  
	    'Callback','nefgui (''loadf'')');  
    [labelStr,accelStr]=menulabel('Sho&w Loops ^w');  
    uimenu(fileHndl,'Label',labelStr, ...  
		'Separator','on', ...  
		'Accelerator',accelStr, ...  
	    'Callback','nefgui (''shwlps'')');  
    [labelStr,accelStr]=menulabel('&Close window ^w');  
    uimenu(fileHndl,'Label',labelStr, ...  
            'Separator','on', ...  
	    'Accelerator',accelStr, ...  
        'Interruptible', 'yes', ...  
	    'Callback','nefgui (''close'')');  
  
    labelStr=menulabel('&Edit ');  
    editHndl=uimenu(h, 'Label',labelStr, 'Tag','editmenu');  
    [labelStr,accelStr]=menulabel('&Input ^i');  
    uimenu(editHndl,'Label',labelStr, ...  
            'Separator','off', ...  
	    'Accelerator',accelStr, ...  
	    'Callback','nefgui_i');  
    [labelStr,accelStr]=menulabel('&Error ^e');  
    uimenu(editHndl,'Label',labelStr, ...  
            'Separator','off', ...  
	    'Accelerator',accelStr, ...  
	    'Callback','nefgui_e');  
    [labelStr,accelStr]=menulabel('&Learning System ^l');  
    uimenu(editHndl,'Label',labelStr, ...  
            'Separator','off', ...  
	    'Accelerator',accelStr, ...  
	    'Callback','nefgui_o');  
    [labelStr,accelStr]=menulabel('&Fuzzy Controller ^f');  
    uimenu(editHndl,'Label',labelStr, ...  
		'Separator','off', ...  
		'Accelerator',accelStr, ...  
		'Callback', ['global NEFCON_FIS;',...  
		        'if NEFCON_FIS~=[], fuzzy(NEFCON_FIS);',...  
		        'else, nefgui(''status'', ''ERROR: Fismatrix is empty'');',...  
		        'end;',...  
		        ]);  
    % build window menu 
    labelStr=menulabel('&Window ');  
    uimenu(h, 'Label', labelStr, ... 
              'Callback', winmenu('callback'), 'Tag', 'winmenu'); 
    winmenu(h);  % Initialize the submenu 
 
    % build help menu 
    labelStr=menulabel('&Help ');  
    helpHndl=uimenu(h, 'Label',labelStr, 'Tag','helpmenu');  
    [labelStr,accelStr]=menulabel('&Help ^h');  
    uimenu(helpHndl,'Label',labelStr, ...  
            'Separator','off', ...  
	    'Accelerator',accelStr, ...  
	    'Callback','hthelp(''nefcon.htm#nefcontr'')');  
 
 
% ---------------------------------------------  
% button frame  
% ---------------------------------------------  
    % The button frame  
    topFrmHndl=uicontrol(h, ...  
        'Style','frame', ...  
       	'Units','normalized', ...  
        'Position',[0 2.5*Nspacing+2*NbtnHt 1 NbtnHt+Nspacing], ...  
        'BackgroundColor',frmColor);  
  
    % create close button  
    closeb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', 'Close', ...  
    	'Units','normalized', ...  
        'Position', [1-Nspacing-NbtnWid 3*Nspacing+2*NbtnHt NbtnWid NbtnHt], ...  
        'CallBack', 'nefgui(''close'')');  
  
    % create help button  
    closeb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', 'Help', ...  
    	'Units','normalized', ...  
        'Position', [1-2*(Nspacing+NbtnWid) 3*Nspacing+2*NbtnHt NbtnWid NbtnHt], ...  
        'CallBack', 'hthelp(''nefcon.htm#nefcontr'')');  
  
    % create reset button  
    resetb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', 'Reset', ...  
    	'Units','normalized', ...  
        'Position', [1-3*(Nspacing+NbtnWid) 3*Nspacing+2*NbtnHt NbtnWid NbtnHt], ...  
        'CallBack', 'nefgui(''reset'')');  
  
    % create create button  
    resetb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', 'Create', ...  
    	'Units','normalized', ...  
        'Position', [0+Nspacing 3*Nspacing+2*NbtnHt NbtnWid NbtnHt], ...  
        'Tag', 'create', ... 
        'CallBack', 'nefgui_c;');  
  
% ---------------------------------------------  
% the status frame  
% ---------------------------------------------  
    % The STATUS frame  
    topFrmHndl=uicontrol(h, ...  
        'Style','frame', ...  
       	'Units','normalized', ...  
        'Position',[0 0 1 2*NbtnHt+2*Nspacing], ...  
        'BackgroundColor',frmColor);  
  
    % The STATUS text window  
    statTxtH=uicontrol(h, ...  
        'Style','text', ...  
    	'BackgroundColor',frmColor, ...  
	    'HorizontalAlignment','left', ...  
        'Position',[Nspacing Nspacing+NbtnHt 1-2*Nspacing-3*NbtnHt NbtnHt], ...  
    	'Units','normalized', ...  
	'Tag','stattxt', ...  
        'String','Status:');  
    stattext = ['Stopped    '; ... 
                'Init       '; ... 
                'Rule P1    '; ... 
                'Rule P2    '; ... 
                'Optimize   '; ... 
                'Control    ']; 
    stwidth = (1-1*Nspacing)/6; 
    NEFCON_SHANDLE = []; 
    for i=1:6 
        if i == 1 
            statTxtH=uicontrol(h, ...  
                'Style','text', ...  
                'BackgroundColor',statdColor, ...  
                'HorizontalAlignment','center', ...  
                'Position',[Nspacing+(i-1)*stwidth Nspacing stwidth*0.95 NbtnHt*0.8], ...  
                'Units','normalized', ...  
                'Tag','status', ...  
                'String',deblank(stattext(i,:))); 
        else 
            statTxtH=uicontrol(h, ...  
                'Style','checkbox', ...  
                'BackgroundColor',statdColor, ...  
                'HorizontalAlignment','center', ...  
                'Position',[Nspacing+(i-1)*stwidth Nspacing stwidth*0.95 NbtnHt*0.8], ...  
                'Units','normalized', ...  
                'Tag','status', ...  
                'CallBack', ['nefgui(''statl'',', int2str(i), ');'], ... 
                'String',deblank(stattext(i,:))); 
        end 
        NEFCON_SHANDLE = [NEFCON_SHANDLE statTxtH]; 
     end 
 
    % create backward button  
    bckb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', '<', ...  
    	'Units','normalized', ...  
        'Position', [1-2*Nspacing-2*NbtnHt 1*Nspacing+NbtnHt NbtnHt NbtnHt], ...  
        'CallBack', ['global NEFCON_STAT NEFCON_RSTATE NEFCON_BTN;' ... 
                     'NEFCON_STAT = NEFCON_STAT - 1;'... 
                     'NEFCON_BTN = 1;' ... 
                     'NEFCON_RSTATE = 0;' ... 
                     'nefgui(''status'');'],... 
	'Tag','bckb');  
 
    % create forward button  
    forwb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', '>', ...  
    	'Units','normalized', ...  
        'Position', [1-1*Nspacing-1*NbtnHt 1*Nspacing+NbtnHt NbtnHt NbtnHt], ...  
        'CallBack', ['global NEFCON_STAT NEFCON_RSTATE NEFCON_BTN;' ... 
                     'NEFCON_STAT = NEFCON_STAT + 1;'... 
                     'NEFCON_BTN = 1;' ... 
                     'NEFCON_RSTATE = 0;' ... 
                     'nefgui(''status'');'],... 
 	'Tag','forwb');  
 
% ---------------------------------------------  
% simulation settings frame  
% ---------------------------------------------  
    left    = Nspacing;  
    bottom  = 5*Nspacing+3*NbtnHt;  
    width   = 1-2*Nspacing;  
    height  = 3*NbtnHt+0*Nspacing;  
    right   = left+width;  
    top     = bottom+height-2*Nspacing;  
  
    % The current settings frame  
    topFrmHndl=uicontrol(h, ...  
        'Style','frame', ...  
       	'Units','normalized', ...  
        'Position',[0 4*Nspacing+3*NbtnHt 1 3*NbtnHt+0*Nspacing], ...  
        'BackgroundColor',frmColor);  
  
   % create simulate button  
   simulateb = uicontrol(h, ...  
      'Style', 'push', ...  
      'String', 'Simulate', ...  
      'Interruptible', 'yes', ...  
      'Units','normalized', ...  
      'Position', [right-NbtnWid bottom NbtnWid NbtnHt], ...  
      'CallBack', [...  
                 'global NEFCON_STOP; NEFCON_STOP=0;', ...  
                 'l = get(gcf, ''CurrentObject'');', ...  
                 'set(l,''enable'',''off'');', ...  
                 'nefgui(''simulate'');'],...  
      'Tag', 'simub');  
  
   % create stop button  
   stopb = uicontrol(h, ...  
      'Style', 'push', ...  
      'Interruptible', 'no', ...  
      'String', 'Stop', ...  
      'enable', 'off', ...  
      'Units','normalized', ...  
      'Position', [right-NbtnWid bottom+NbtnHt+Nspacing NbtnWid NbtnHt], ...  
      'CallBack', [...  
                 'global NEFCON_STOP; NEFCON_STOP=1;', ...  
                 'l = get(gcf, ''CurrentObject'');', ...  
                 'set(l,''enable'',''off'');'],...  
      'Tag', 'stopb');  
  
    % start/stop time  
    tmp = uicontrol(h, ...  
        'Style','text', ...  
    	'BackgroundColor',frmColor, ...  
        'HorizontalAlignment','left', ...  
        'Position', [left top-NbtnHt NbtnWid NbtnHt], ...  
        'Units', 'normalized', ...  
        'String', 'Start time');  
    tmp = uicontrol(h, ...  
        'Style','edit', ...  
        'BackgroundColor',editColor, ...  
        'HorizontalAlignment','left', ...  
        'Position', [left+NbtnWid+Nspacing top-NbtnHt NbtnWid NbtnHt], ...  
        'Units', 'normalized',...  
        'CallBack', 'nefgui(''start'')', ...  
        'String', get_param(NEFCON_SYSNAME,'Start time'), ...  
        'Tag', 'start');  
    tmp = uicontrol(h, ...  
        'Style','text', ...  
        'BackgroundColor',frmColor, ...  
        'HorizontalAlignment','left', ...  
        'Position', [left top-Nspacing-2*NbtnHt NbtnWid NbtnHt], ...  
        'Units', 'normalized', ...  
        'String', 'Stop time');  
    tmp = uicontrol(h, ...  
        'Style','edit', ...  
        'BackgroundColor',editColor, ...  
        'HorizontalAlignment','left', ...  
        'Position', [left+NbtnWid+Nspacing top-Nspacing-2*NbtnHt NbtnWid NbtnHt], ...  
        'Units', 'normalized',...  
        'CallBack', 'nefgui(''stop'')', ...  
        'String', get_param(NEFCON_SYSNAME,'Stop time'), ...  
        'Tag', 'stop');  
    tmp = uicontrol(h, ...  
        'Style','text', ...  
        'BackgroundColor',frmColor, ...  
        'HorizontalAlignment','left', ...  
        'Position', [left+2*(NbtnWid+Nspacing) top-NbtnHt NbtnWid NbtnHt], ...  
        'Units', 'normalized', ...  
        'String', 'Step Size');  
    tmp = uicontrol(h, ...  
        'Style','edit', ...  
        'BackgroundColor',editColor, ...  
        'HorizontalAlignment','left', ...  
        'Position', [left+3*(NbtnWid+Nspacing) top-NbtnHt NbtnWid NbtnHt], ...  
        'Units', 'normalized',...  
        'CallBack', 'nefgui(''step'')', ...  
        'String', get_param(NEFCON_SYSNAME,'min step size'), ...  
        'Tag', 'step');  
    tmp = uicontrol(h, ...  
        'Style','text', ...  
        'BackgroundColor',frmColor, ...  
        'HorizontalAlignment','left', ...  
        'Position', [left+2*(NbtnWid+Nspacing) top-Nspacing-2*NbtnHt NbtnWid NbtnHt], ...  
        'Units', 'normalized', ...  
        'String', 'Cycles');  
    tmp = uicontrol(h, ...  
        'Style','edit', ...  
        'BackgroundColor',editColor, ...  
        'HorizontalAlignment','left', ...  
        'Position', [left+3*(NbtnWid+Nspacing) top-Nspacing-2*NbtnHt NbtnWid NbtnHt], ...  
        'Units', 'normalized',...  
        'CallBack', 'nefgui(''cycles'')', ...  
        'Tag', 'cycles');  
  
% ---------------------------------------------  
% nefcon main frame  
% ---------------------------------------------  
    left    = Nspacing;  
    bottom  = 3*Nspacing+6*NbtnHt;  
    width   = 1-Nspacing;  
    height  = 1-bottom-Nspacing;  
    right   = left+width;  
    top     = bottom+height;  
  
    % The nefcon frame label  
    labelStr='The NEFCON Model';  
    statHndl=uicontrol(h, ...  
        'Style','text', ...  
        'BackgroundColor',bckfrmColor, ...  
        'HorizontalAlignment','center', ...  
        'Position', [left+Nspacing top-NbtnHt width-2*Nspacing NbtnHt], ...  
        'Units', 'normalized', ...  
        'String', labelStr);  
  
% ---------------------------------------------  
% nefcon graphic  
% ---------------------------------------------  
   ferr = uicontrol(h, 'style','pushbutton',...  
                'position',[left+NbtnHt top-4*NbtnHt width/3 3*NbtnHt],...  
             'Units','normalized', ...  
                'Interruptible','yes', ...  
                'BackgroundColor',blockColor, ...  
                'Callback', ...  
                [ ...  
                'ferr = get(gcf, ''CurrentObject'');', ...  
                'set(ferr,''enable'',''off'');', ...  
                'nefgui_e;',...  
                'set(ferr,''enable'',''on'');', ...  
                ], ...  
                'string','Error Definition');  
  
  
    % create connecting arrow  
    Xstart = left+NbtnHt + width/3;  
    Xend = left+NbtnHt + width/2;  
    Ystart = top-2.5*NbtnHt;  
    Yend = Ystart;  
    arrow('start', [Xstart Ystart],...  
          'stop', [Xend Yend], ...  
          'linewidth', 2, ...  
          'color', lineColor);  
  
  
    % The Nefcon Learning algor.  
    left = left + width/2;  
    lea = uicontrol(h, 'style','pushbutton',...  
                'position',[left+NbtnHt top-4*NbtnHt width/3 3*NbtnHt],...  
             'Units','normalized', ...  
                'Interruptible','yes', ...  
                'BackgroundColor',blockColor, ...  
                'Callback', ...  
                [ ...  
                'lea = get(gcf, ''CurrentObject'');', ...  
                'set(lea,''enable'',''off'');', ...  
                'nefgui_o;',...  
                'set(lea,''enable'',''on'');', ...  
                ], ...  
                'string',['Learning Algorithm']);  
  
    % create connecting arrow  
    Xstart = left+NbtnHt + width/6;  
    Xend = Xstart;  
    Ystart = top-4*NbtnHt;  
    Yend = top-height/3-2*NbtnHt;  
    arrow('start', [Xstart Ystart],...  
          'stop', [Xend Yend], ...  
          'linewidth', 3, ...  
          'color', lineColor, ...  
          'ends', 3, ...  
          'length', spacing, ...  
          'tipangle', 40);  
  
    % The Fuzzy Controller  
    top = top - height/3;  
    con = uicontrol(h, 'style','pushbutton',...  
                'position',[left+NbtnHt top-5*NbtnHt width/3 3*NbtnHt],...  
             'Units','normalized', ...  
                'Interruptible','no', ...  
                'BackgroundColor',blockColor, ...  
                'enable', 'off', ...  
                'Callback',...  
                [ ...  
                'con = get(gcf, ''CurrentObject'');', ...  
                'set(con,''enable'',''off'');', ...  
                'global NEFCON_FIS;',...  
                'if NEFCON_FIS~=[], fuzzy(NEFCON_FIS);',...  
                'else, nefgui(''status'', ''ERROR: Fismatrix is empty'');',...  
                'end;',...  
                'set(con,''enable'',''on'');', ...  
                ], ...  
                'string','Fuzzy Controller', ...  
                'tag', 'fuzzyc');  
  
    % create connecting arrow  
    Xstart = left+NbtnHt - width/2 + width/3;  
    Xend = left+NbtnHt;  
    Ystart = top-3.5*NbtnHt;  
    Yend = Ystart;  
    % input to fuzzy  
    arrow('start', [Xstart Ystart],...  
          'stop', [Xend Yend], ...  
          'linewidth', 2, ...  
          'color', lineColor);  
    % input to error  
    Xstart = Xstart + (Xend-Xstart)*0.5;  
    Xend = Xstart - (Xend-Xstart)*0.5 - width/5;  
    Ystart = Ystart;  
    Yend = top - 4*NbtnHt + height/3;  
    line([Xstart Xstart Xend],[Ystart Ystart+height*0.18 Ystart+height*0.18], ...  
        'LineStyle', '-', ...  
        'LineWidth',2, ...  
        'Color',lineColor);  
    arrow('start', [Xend Ystart+height*0.18],...  
          'stop', [Xend Yend], ...  
          'linewidth', 2, ...  
          'color', lineColor);  
  
  
    % create output arrow  
    Xstart = left+NbtnHt + width/3;  
    Xend = right;  
    Ystart = top-3.5*NbtnHt;  
    Yend = Ystart;  
    % output  
    arrow('start', [Xstart Ystart],...  
          'stop', [Xend Yend], ...  
          'linewidth', 2, ...  
          'color', lineColor);  
    % output to learning  
    Xstart = Xstart + (Xend-Xstart)*0.5;  
    Xend = left+NbtnHt + width/3;  
    Ystart = Ystart;  
    Yend = top - 2.5*NbtnHt + height/3;  
    line([Xstart Xstart],[Ystart Yend], ...  
        'LineStyle', '-', ...  
        'LineWidth',2, ...  
        'Color',lineColor);  
    arrow('start', [Xstart Yend],...  
          'stop', [Xend Yend], ...  
          'linewidth', 2, ...  
          'color', lineColor);  
  
  
    % The Input Preprocessing  
    left = left - width/2;  
    inp = uicontrol(h, 'style','pushbutton',...  
                'position',[left+NbtnHt top-5*NbtnHt width/3 3*NbtnHt],...  
             'Units','normalized', ...  
                'Interruptible','yes', ...  
                'BackgroundColor',blockColor, ...  
                'Callback', ...  
                [ ...  
                'inp = get(gcf, ''CurrentObject'');', ...  
                'set(inp,''enable'',''off'');', ...  
                'nefgui_i;',...  
                'set(inp,''enable'',''on'');', ...  
                ], ...  
                'string','Input Preprocessing');  
  
    tmp = uicontrol(h, ...  
        'Style','text', ...  
    	'BackgroundColor',blockColor, ...  
        'HorizontalAlignment','center', ...  
        'Position', [left+2*NbtnHt top-5*NbtnHt+Nspacing width/3-2*NbtnHt NbtnHt*0.8], ...  
        'Units', 'normalized', ...  
        'String', '( 2 inputs )', ...  
        'tag', 'nofinp');  
  
    % input arrow  
    Xstart = left;  
    Xend = left+NbtnHt;  
    Ystart = top - 3.5*NbtnHt;  
    Yend = Ystart;  
    arrow('start', [Xstart Ystart],...  
          'stop', [Xend Yend], ...  
          'linewidth', 2, ...  
          'color', lineColor);   
  
  
% ---------------------------------------------  
% variable initilization  
% ---------------------------------------------  
  
 
    NEFCON_NOISE=0;    
  
    NEFCON_UIH = h;  
    if NEFCON_STAT == [],  
        NEFCON_STAT = 0;  
    end  
 
    if NEFCON_STAT == 0 
        path = [pwd '/']; 
        fn = [ NEFCON_SYSNAME, '.nef' ]; 
        if exist([path fn]) 
        %        ans = questdlg(['Load settings? (' fn ')'],'Yes','No'); 
            ans = 'Yes'; 
            if strcmp(ans, 'Yes') 
                eval(['load ' [path fn] ' -mat; nefmat(nefsmat);']);     % loads matrix smat  
                nefgui('status', 'INFO: Settings loaded.');  
            end 
        end 
    end 
      
	% set actual gain and interval settings and initialize all undefined globals
	NEFCON_INT = [];
	NEFCON_GAIN = [];
    nefdef;  

	% update display
    nefgui('cycles', 'set');  
    nefgui('nofinp');  
    nefgui('status');  
    tagset(NEFCON_UIH, 'status', 'Value', 1);   

elseif strcmp(action, 'close'),  
    % close current nefgui  
    % matlab dialog error using button... 
    %ans = questdlg('Save current settings?','Yes','No','Cancel','Yes'); 
    ans = 'Yes'; 
    if strcmp(ans, 'Yes') 
        path = [pwd '/']; 
        fn = [ NEFCON_SYSNAME, '.nef' ]; 
        eval(['nefsmat = nefmat; save ' [path fn] ' nefsmat;']);  
        set(NEFCON_UIH,'visible','off');  
%        close(gcf);  
%        NEFCON_UIH = []; 
    elseif strcmp(ans, 'No') 
        set(NEFCON_UIH,'visible','off');  
%        close(gcf);  
%        NEFCON_UIH = []; 
    end     
  
  
elseif strcmp(action, 'status'),  
    if NEFCON_STAT == [], 
        NEFCON_STAT = 1; 
    end 
    if nargin < 2,  
        p1 = ''; 
    end  
  
    hndl=findobj(NEFCON_UIH, 'Tag','status');  
    if hndl == [],  
        % control is probably closed - clear global NEFCON_UIH to prevent subsequent calls...  
        NEFCON_UIH = [];  
    else  
        % reset all colors 
        set(hndl, 'BackgroundColor',statdColor); 
        if NEFCON_STAT >=1 &  NEFCON_STAT <=5 
            set(NEFCON_SHANDLE(NEFCON_STAT+1), 'BackgroundColor',yellow); 
            % redraw text - delay in X-Systems 
            set(NEFCON_SHANDLE(NEFCON_STAT+1), 'String', get(NEFCON_SHANDLE(NEFCON_STAT+1), 'String')); 
        elseif NEFCON_STAT ==0  
            set(NEFCON_SHANDLE(NEFCON_STAT+1), 'BackgroundColor',stateColor); 
        end  
        hndl=findobj(NEFCON_UIH, 'Tag','stattxt');  
        if NEFCON_ACTCYC == [] | NEFCON_ACTCYC == 0 
            set(hndl, 'String', ['Status: ' p1]);  
        else  
            set(hndl, 'String', ['Status: ' p1 '  [Cycle: ' num2str(NEFCON_ACTCYC) ']']);  
        end  
        drawnow; 
    end  
  
    % enable/disable create button  
    if NEFCON_STAT == 0  
        tagset(NEFCON_UIH, 'create', 'enable','on');  
    else  
        tagset(NEFCON_UIH, 'create', 'enable','off');  
    end  
 
    % enable/disable simulate button  
    hndl=findobj(NEFCON_UIH, 'Tag','simub');  
    if NEFCON_STAT == 0 | NEFCON_STOP == 1 
        set(hndl,'enable','on');  
    else  
        set(hndl,'enable','off');  
    end  
    if NEFCON_STOP == 1 
        set(hndl,'String','Continue');  
    else 
        set(hndl,'String','Simulate');  
    end  
 
    % enable/disable stop button  
    hndl=findobj(NEFCON_UIH, 'Tag','stopb');  
    if NEFCON_STAT == 0 | NEFCON_STOP == 1 
        set(hndl,'enable','off');  
    else  
        set(hndl,'enable','on');  
    end  
  
    % enable/disable skip buttons  
    hndl=findobj(NEFCON_UIH, 'Tag','bckb');  
    if NEFCON_STAT > 2 & NEFCON_STAT < 6  
        set(hndl,'enable','on');  
    else  
        set(hndl,'enable','off');  
    end  
    hndl=findobj(NEFCON_UIH, 'Tag','forwb');  
    if NEFCON_STAT > 0 & NEFCON_STAT < 5  
        set(hndl,'enable','on');  
    else  
        set(hndl,'enable','off');  
    end  
 
    % enable/disable fuzzy controller button  
    hndl=findobj(NEFCON_UIH, 'Tag','fuzzyc');  
    if NEFCON_FIS == []  
        set(hndl,'enable','off');  
    else  
        set(hndl,'enable','on');  
    end  
  
    %enable/disable other tools  
    nefgui_o('actualize');  
  
 
elseif strcmp(action, 'statl') 
    if p1 ~= [] 
        if NEFCON_STAT == 0  
            NEFCON_STATEX(p1-1) = get(NEFCON_SHANDLE(p1), 'Value');  
        else  
            nefgui('status','NEFCON: Could not change setting during execution.');  
            set(NEFCON_SHANDLE(p1), 'Value', NEFCON_STATEX(p1-1));  
        end  
    end 
 
elseif strcmp(action, 'rulelist'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'rulelist');  
    if hndl ~= [],  
        if NEFCON_STAT == 0,  
            NEFCON_RULE = get(hndl, 'Value');  
        else  
            disp('NEFCON: Could not change rule-learning during execution.');  
            set(hndl, 'Value', NEFCON_RULE);  
        end  
    end  
  
elseif strcmp(action, 'opt'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'opt');  
    if hndl ~= [],  
        if NEFCON_STAT == 0,  
            NEFCON_OPT = get(hndl, 'Value');  
        else  
            nefgui('status', 'INFORMATION: optimization type changed.');  
            NEFCON_OPT = get(hndl, 'Value');  
%            disp('NEFCON: Could not change optimization type during execution.');  
%            set(hndl, 'Value', NEFCON_OPT);  
        end  
    end  
  
elseif strcmp(action, 'ferr'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'ferr');  
    if hndl ~= [],  
        if NEFCON_STAT == 0,  
            NEFCON_FERR = get(hndl, 'Value');  
        else  
            disp('NEFCON: Could not change error type during execution.');  
            set(hndl, 'Value', NEFCON_FERR);  
        end  
    end  
  
elseif strcmp(action, 'inifismat'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'inifismat');  
    if hndl ~= [],  
        if NEFCON_STAT == 0,  
            NEFCON_IFM = get(hndl, 'String');  
        else  
            disp('NEFCON: Could not change initial fismatrix during execution.');  
            set(hndl, 'String', NEFCON_IFM);  
        end  
    end  
  
elseif strcmp(action, 'errfismat'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'errfismat');  
    if hndl ~= [],  
        if NEFCON_STAT == 0,  
            NEFCON_EFMN = get(hndl, 'String');  
        else  
            disp('NEFCON: Could not change error fismatrix during execution.');  
            set(hndl, 'String', NEFCON_EFMN);  
        end  
    end  
  
elseif strcmp(action, 'rate'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'rate');  
    if hndl ~= [],  
        data = str2num(get(hndl, 'String'));  
        if data<0,  
            nefgui('status', 'ERROR: Rate must be positive.')  
            set(hndl, 'String', num2str(NEFCON_RATE));  
        else  
            NEFCON_RATE = data;  
            if NEFCON_STAT > 0,  
                nefgui('status', 'INFO: Rate changed.');  
            end  
        end  
    end  
  
elseif strcmp(action, 'load'),  
    [fn, path] = uigetfile ('*.nef', 'Load Nefcon settings');  
    if fn ~= 0  
        %load settings  
        if exist([path fn]) == 0  
            nefgui('status', 'WARNING: File not found!');  
        else  
            % set globals  
            eval(['load ' [path fn] ' -mat; nefmat(nefsmat);']);     % loads matrix smat  
            nefgui('status', 'INFO: Settings loaded.');  
            % update display 
            nefgui('cycles', 'set');  
            nefgui('nofinp');  
        end  
    end  
  
elseif strcmp(action, 'save'),  
    [fn, path] = uiputfile ('*.nef', 'Save Nefcon settings');  
    if fn == 0  
        nefgui('status', 'WARNING: Settings not saved!');  
    else  
        %get current settings  
        if find(fn=='.') == []  
            % append filename extension (error in uiputfile: appends .mat)  
            fn = [fn '.nef'];         
        end  
        eval(['nefsmat = nefmat; save ' [path fn] ' nefsmat;']);  
        nefgui('status', 'INFO: Settings saved.');  
    end  
  
elseif strcmp(action, 'new'),  
    %load default settings  
    if exist('default.nef') == 0  
        nefgui('status', 'WARNING: File ''default.nef'' not found!');  
    else  
        % set globals  
        eval(['load default.nef -mat; nefmat(nefsmat);']);     % loads matrix smat  
        nefgui('status', 'INFO: Default settings loaded.');  
    end  
  
elseif strcmp(action, 'savef'),  
    if NEFCON_FIS == []  
        nefgui('status', 'ERROR: Fismatrix is empty.');  
    else  
        [fn, path] = uiputfile ('*.fis', 'Save Nefcon fismatrix');  
        if fn == 0  
            nefgui('status', 'WARNING: Matrix not saved!');  
        else  
            %save  
            if find(fn=='.') == []  
                % append filename extension (error in uiputfile: appends .mat)  
                fn = [fn '.fis'];   
            end  
            writefis(NEFCON_FIS, [path fn]);  
            nefgui('status', 'INFO: Matrix saved.');  
        end  
    end  
  
elseif strcmp(action, 'loadf'),  
    [fn, path] = uigetfile ('*.fis', 'Load Nefcon fismatrix');  
    if fn ~= 0  
        %load  
        if exist([path fn]) == 0  
            nefgui('status', 'WARNING: File not found!');  
        else  
            % set  
            NEFCON_FIS = readfis([path fn]);  
            nefgui('status', 'INFO: Matrix loaded.');  
        end  
    end  
 
elseif strcmp(action, 'start'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'start');  
    if hndl ~= [],  
        data = str2num(get(hndl, 'String'));  
        if data<0,  
            nefgui('status', 'ERROR: Illegal Number.')  
            set(hndl, 'String', get_param(NEFCON_SYSNAME,'Start time'));  
        else  
            set_param(NEFCON_SYS,'Start time', num2str(data))  
        end  
    end  
elseif strcmp(action, 'stop'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'stop');  
    if hndl ~= [],  
        data = str2num(get(hndl, 'String'));  
        if data<0,  
            nefgui('status', 'ERROR: Illegal Number.')  
            set(hndl, 'String', get_param(NEFCON_SYSNAME,'Stop time'));  
        else  
            set_param(NEFCON_SYSNAME,'Stop time', num2str(data))  
        end  
    end  
elseif strcmp(action, 'step'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'step');  
    if hndl ~= [],  
        data = str2num(get(hndl, 'String'));  
        if data<0,  
            nefgui('status', 'ERROR: Illegal Number.')  
            set(hndl, 'String', get_param(NEFCON_SYSNAME,'Min step size'));  
        else  
            set_param(NEFCON_SYSNAME,'Min step size', num2str(data))  
            set_param(NEFCON_SYSNAME,'Max step size', num2str(data))  
        end  
    end  
elseif strcmp(action, 'cycles'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'cycles');  
    if hndl ~= [],  
        if nargin<2, % set from input  
            data = str2num(get(hndl, 'String'));  
            if data<1,  
                nefgui('status', 'ERROR: Illegal Number.')  
                set(hndl, 'String', num2str(NEFCON_CYC));  
            else  
                NEFCON_CYC = data;  
            end  
        else  
            if NEFCON_RBT == 3 & NEFCON_RBT1 == 3 & NEFCON_OBT == 3,  
               NEFCON_CYC = NEFCON_RBND + NEFCON_RBND1 + NEFCON_OBND;    % nof cycles  
            end  
            set(hndl, 'String', num2str(NEFCON_CYC));  
        end  
    end  
elseif strcmp(action, 'nofinp'),  
    hndl=findobj(NEFCON_UIH, 'Tag', 'nofinp');  
    if hndl ~= [],  
        set(hndl, 'String', ['( ' num2str(NEFCON_NUMIN) ' inputs )']);  
    end  
 
elseif strcmp(action, 'simulate'),  
    hndl=findobj(NEFCON_UIH, 'Tag','simub');  
    if hndl ~= [],  
        % reset time/states for simulate 
        if strcmp(setstr(get(hndl, 'string')), 'Simulate') 
            NEFCON_TIME = []; 
            NEFCON_X0 = []; 
            NEFCON_YS = []; 
            NEFCON_ACTCYC = 0;  
        end 
    end 
    nefsim;  
 
elseif strcmp(action, 'shwlps'),  
    [fn, path] = uigetfile ('*.mat', 'Select loop directory');  
    if path ~= 0  
		nefdlp(path);
    end  

elseif strcmp(action, 'reset'),  
    %clear all;  
    NEFCON_STOP = 0;  
    NEFCON_STAT = 0;  
    NEFCON_ACTCYC = 0;  
    nefdef;  
    nefgui('status');  
    nefgui('rulelist');  
    nefgui('opt');  
    nefgui('rate');  
    nefgui('ferr');  
    nefgui('inifismat');  
    nefgui('errfismat');  
    nefgui('cycles', 'set'); 
    tagset(NEFCON_UIH, 'status', 'Value', 1);   
    NEFCON_STATEX = ones(1, 7); 
  
elseif strcmp(action, ''),  
    % popup window  
    nefgui('cycles', NEFCON_CYC);  
    set(NEFCON_UIH,'visible','on');  
    figure(NEFCON_UIH); 
  
else  
    disp(['nefgui: illegal action (' action ')']);  
end  
  
