function nefgui_o(action, p1);   
   
%NEFGUI_O GUI-Tool to manage Nefcon learning algorithm settings. 
% 
% See also NEFGUI, NEFGUI_E, NEFGUI_I and NEFCON.  
   
% Author: Andreas Nuernberger, TU Braunschweig, August 1996; a.nuernberger@tu-bs.de
%         contact: Ludger Merz, DASA-Airbus GmbH, Hamburg; ludger.merz@airbus.de
   
% Globals: Description in nefmat  
global NEFCON_PROT NEFCON_STAT NEFCON_UIH NEFCON_RULE NEFCON_OPT NEFCON_IFM NEFCON_EFM NEFCON_EFMN   
global NEFCON_RATE NEFCON_FERR NEFCON_FIS   
global NEFCON_RBT NEFCON_RBND NEFCON_RBT1 NEFCON_RBND1 NEFCON_OBT NEFCON_OBND   
global NEFCON_CYC NEFCON_NOISE NEFCON_ADDR 
global NEFCON_GENN NEFCON_MFIN NEFCON_MFOUT NEFCON_MFIT NEFCON_MFOT 
global NEFCON_RRATE NEFCON_RPER  
 
handle = findobj('Tag', 'NEFCONGUI_O');   
   
if nargin < 1    
    if handle == []   
        action = 'initialize';   
    else   
        action = '';   
    end;   
end;   
   
%create controls   
if strcmp(action, 'initialize') & handle == [],   
    % Information for all objects   
    bckfrmColor=230/255*[1 1 1];   
    frmColor=192/255*[1 1 1];   
    bckColor=230/255*[1 1 1];   
    btnColor=192/255*[1 1 1];   
    popupColor=192/255*[1 1 1];   
    editColor=255/255*[1 1 1];   
    border=6;   
    spacing=8;   
   
    %Calculate Windowsize   
    figPos=get(0,'DefaultFigurePosition');   
    figPos(3) = 1. * figPos(3);   
    figPos(4) = 0.9 * figPos(3);   
    maxRight=figPos(3);   
    maxTop=figPos(4);   
   
    % uicontrol sizes   
%    btnWid  = 110;   
%    btnHt   = 23;   
    btnWid = maxRight/6;   
    btnHt  = maxRight/25;   
   
    % calculate normalized units for resizeable window   
    Nborder = border/maxRight;   
    Nspacing= spacing/maxRight;   
    NbtnWid = btnWid/maxRight;   
    NbtnHt  = btnHt/maxTop;   
   
    % userdata   
    localdata = [];   
   
    % open new window   
    h = figure( ...   
        'Name','Learning Algorithm', ...   
        'NumberTitle','off', ...   
    	'Color',bckColor, ...   
	    'Visible','on', ...   
	    'UserData',localdata, ...   
    	'Units','pixels', ...   
	    'DefaultAxesXColor','black', ...   
    	'DefaultAxesYColor','black', ...   
    	'MenuBar','none', ...   
	    'Resize','on', ...   
	    'Position',figPos, ...   
    	'Nextplot','new', ...   
    	'Tag','NEFCONGUI_O' ...   
	    );   
    figPos=get(h,'position');   
   
    % create close button   
    closeb = uicontrol(h, ...   
        'Style', 'push', ...   
        'String', 'Close', ...   
    	'Units','normalized', ...   
        'Position', [1-Nspacing-NbtnWid 3*Nspacing+NbtnHt NbtnWid NbtnHt], ...   
        'CallBack', 'nefgui_o(''close'')');   
   
    % create help button  
    helpb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', 'Help', ...  
    	'Units','normalized', ...  
        'Position', [1-Nspacing-NbtnWid 2*(3*Nspacing+NbtnHt) NbtnWid NbtnHt], ...  
        'CallBack', 'hthelp(''nefcon.htm#learnalgo'')');  
  
    % create show fis button   
    showb = uicontrol(h, ...   
        'Style', 'push', ...   
        'enable', 'off', ...  
        'tag', 'showb', ...  
        'String', 'Show MF', ...   
    	'Units','normalized', ...   
        'Position', [1-Nspacing-NbtnWid 1-(3*Nspacing+NbtnHt) NbtnWid NbtnHt], ...   
        'CallBack', 'global NEFCON_FIS; h=figure; act=gcf; figure(h); dispmfs(NEFCON_FIS);figure(act);');   
   
    % create show rules button   
    editR = uicontrol(h, ...   
        'Style', 'push', ...   
        'enable', 'off', ...  
        'tag', 'editR', ...  
        'String', 'Edit Rules', ...   
    	'Units','normalized', ...   
        'Position', [1-Nspacing-NbtnWid 1-2*(3*Nspacing+NbtnHt) NbtnWid NbtnHt], ...   
        'CallBack', 'global NEFCON_FIS; ruleedit(NEFCON_FIS);');   
 
    % create show surface button   
    editR = uicontrol(h, ...   
        'Style', 'push', ...   
        'enable', 'off', ...  
        'tag', 'showS', ...  
        'String', 'Surface', ...   
    	'Units','normalized', ...   
        'Position', [1-Nspacing-NbtnWid 1-3*(3*Nspacing+NbtnHt) NbtnWid NbtnHt], ...   
        'CallBack', 'global NEFCON_FIS; surfview(NEFCON_FIS);');   
   
    % create edit fis button   
    editb = uicontrol(h, ...   
        'Style', 'push', ...   
        'enable', 'off', ...  
        'tag', 'editb', ...  
        'String', 'Edit Fis', ...   
    	'Units','normalized', ...   
        'Position', [1-Nspacing-NbtnWid 1-4*(3*Nspacing+NbtnHt) NbtnWid NbtnHt], ...   
        'CallBack', 'global NEFCON_FIS; fuzzy(NEFCON_FIS);');   
   
    % The STATUS frame   
    topFrmHndl=uicontrol(h, ...   
        'Style','frame', ...   
       	'Units','normalized', ...   
        'Position',[0 0 1 NbtnHt+2*Nspacing], ...   
        'BackgroundColor',frmColor);   
   
    % The STATUS text window   
    statTxtH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position',[Nspacing Nspacing 1-2*Nspacing NbtnHt], ...   
    	'Units','normalized', ...   
	    'Tag','status', ...   
        'String','');   
   
    % The Options frame   
    left    = Nspacing;   
    bottom  = 3*Nspacing+1*NbtnHt;   
    width   = 0.8-Nspacing;   
    height  = 1-bottom-Nspacing;   
    right   = left+width;   
    top     = bottom+height;   
%    topFrmHndl=uicontrol(h, ...   
%        'Style','frame', ...   
%       	'Units','normalized', ...   
%        'Position',[left bottom width height], ...   
%        'BackgroundColor',bckfrmColor);   
   
    % The Options frame label   
%    labelStr='Nefcon Options';   
%    statHndl=uicontrol(h, ...   
%        'Style','text', ...   
%    	'BackgroundColor',bckfrmColor, ...   
%	    'HorizontalAlignment','center', ...   
%        'Position', [left+Nspacing top-Nspacing-NbtnHt width-2*Nspacing NbtnHt], ...   
%    	'Units', 'normalized', ...   
%        'String', labelStr);   
   
    % The Options rule learning   
    NofLines = 9;   
    left    = left + Nspacing;   
    height  = NofLines*(Nspacing+NbtnHt) + Nspacing;   
%    bottom  = top - 2*Nspacing-NbtnHt - height;   
    bottom  = 1 - 2*Nspacing - height;   
    width   = width - 2*Nspacing;   
    right   = left+width;   
    top     = bottom+height;   
    topFrmHndl=uicontrol(h, ...   
        'Style','frame', ...   
       	'Units','normalized', ...   
        'Position',[left bottom width height], ...   
        'BackgroundColor',frmColor);   
   
    statHndl=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','center', ...   
        'Position', [left+Nspacing top-Nspacing-NbtnHt width-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'Rule Learning');   
   
    rulelistH=uicontrol(h, ...   
        'Style','popup', ...   
    	'BackgroundColor',editColor, ...   
        'String', 'Bottom-Up learning|Nefcon|disabled - initial fismatrix|disabled - use actual fismatrix',...   
        'Position', [left+Nspacing top-2*(Nspacing+NbtnHt) width-3*Nspacing-NbtnHt NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''rulelist'')', ...   
        'Tag', 'rulelist');   
%        'String', 'Bottom-Up learning|Nefcon|Partitionlearning|disabled - initial fismatrix|disabled - use actual fismatrix',...   
    helpb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', '?', ...  
    	'Units','normalized', ...  
        'Position', [left+width-Nspacing-NbtnHt top-2*(Nspacing+NbtnHt) NbtnHt NbtnHt], ...  
        'CallBack', 'hthelp(''nefcon.htm#ruleopt'')');  
   
    statHndl=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing top-3*(Nspacing+NbtnHt) width/3-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'fismatrix:');   
    inifismatH=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+width/3+Nspacing top-3*(Nspacing+NbtnHt) width*2/3-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''inifismat'')', ...   
    	'Tag','inifismat');   
% Partitioning 
    topFrmHndl=uicontrol(h, ...   
        'Style','frame', ...   
       	'Units','normalized', ...   
        'Position',[left+Nspacing/2 top-5*(Nspacing+NbtnHt)-Nspacing/2 width-Nspacing 2*(Nspacing+NbtnHt)], ...   
        'BackgroundColor',frmColor);   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing top-4*(Nspacing+NbtnHt) width*0.3-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'Partitioning:');   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing+width*0.3 top-4*(Nspacing+NbtnHt) width*0.2-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'Input:');   
    partinH=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width*0.5 top-4*(Nspacing+NbtnHt) width*0.1-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''partin'')', ...   
    	'Tag','partin');   
    mfitH=uicontrol(h, ...   
        'Style','popup', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width*0.6 top-4*(Nspacing+NbtnHt) width*0.3-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'trimf/trapmf|gaussmf',...   
        'CallBack', 'nefgui_o (''mfit'')', ...   
        'Tag', 'mfit');   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing+width*0.9 top-4*(Nspacing+NbtnHt) width*0.1-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'MFs');   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing+width*0.3 top-5*(Nspacing+NbtnHt) width*0.2-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'Output:');   
    partoutH=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width*0.5 top-5*(Nspacing+NbtnHt) width*0.1-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''partout'')', ...   
    	'Tag','partout');   
    mfotH=uicontrol(h, ...   
        'Style','popup', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width*0.6 top-5*(Nspacing+NbtnHt) width*0.3-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'trimf|gaussmf',...   
        'CallBack', 'nefgui_o (''mfot'')', ...   
        'Tag', 'mfot');   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing+width*0.9 top-5*(Nspacing+NbtnHt) width*0.1-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'MFs');   
 
    noiseH=uicontrol(h, ...   
        'Style','checkbox', ...   
    	'BackgroundColor',frmColor, ...   
        'Position', [left+Nspacing top-6*(Nspacing+NbtnHt) width*0.4 NbtnHt], ...   
    	'Units', 'normalized', ... 
        'String', 'generate noise', ...   
        'CallBack', 'nefgui_o (''noise'')', ...   
    	'Tag','noise');   
 
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing+width*0.45 top-6*(Nspacing+NbtnHt) width*0.25 NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'learn. rate:', ...   
    	'Tag','rlrt');   
    rlrH=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width*0.75 top-6*(Nspacing+NbtnHt) width*0.2 NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''rlr'')', ...   
    	'Tag','rlr');   
   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing top-7*(Nspacing+NbtnHt) width*0.55 NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'Delete rules used less than', ...   
    	'Tag','rlrt');   
    rrmH=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width*0.56 top-7*(Nspacing+NbtnHt) width*0.1 NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''rrm'')', ...   
    	'Tag','rrm');   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing+width*0.7 top-7*(Nspacing+NbtnHt) width*0.2 NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'percent', ...   
    	'Tag','rlrt');   
 
    topFrmHndl=uicontrol(h, ...   
        'Style','frame', ...   
       	'Units','normalized', ...   
        'Position',[left+Nspacing/2 bottom+Nspacing/2 width-Nspacing 2*(Nspacing+NbtnHt)], ...   
        'BackgroundColor',frmColor);   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing top-8*(Nspacing+NbtnHt) width/5-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'Phase 1: ');   
    rbndH=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width/5 top-8*(Nspacing+NbtnHt) width/5-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''rbnd'')', ...   
    	'Tag','rbnd');   
    rbtH=uicontrol(h, ...   
        'Style','popup', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+width*0.4+Nspacing top-8*(Nspacing+NbtnHt) width*0.6-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'time steps [s]|iteration steps|cycles',...   
        'CallBack', 'nefgui_o (''rbt'')', ...   
        'Tag', 'rbt');   
     s1H=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing top-9*(Nspacing+NbtnHt) width/5-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...  
        'String', 'Phase 2: ');   
    rbnd1H=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width/5 top-9*(Nspacing+NbtnHt) width/5-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''rbnd1'')', ...   
    	'Tag','rbnd1');   
    rbt1H=uicontrol(h, ...   
        'Style','popup', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+width*0.4+Nspacing top-9*(Nspacing+NbtnHt) width*0.6-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'time steps [s]|iteration steps|cycles',...   
        'CallBack', 'nefgui_o (''rbt1'')', ...   
        'Tag', 'rbt1');   
 
    % The Options optimization   
    NofLines = 5;   
    left    = left;   
    height  = NofLines*(Nspacing+NbtnHt) + Nspacing;   
    top     = bottom - Nspacing;   
    width   = width;   
    right   = left+width;   
    bottom  = top-height;   
    topFrmHndl=uicontrol(h, ...   
        'Style','frame', ...   
       	'Units','normalized', ...   
        'Position', [left bottom width height], ...   
        'BackgroundColor',frmColor);   
   
    statHndl=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','center', ...   
        'Position', [left+Nspacing top-Nspacing-NbtnHt width-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'Optimization');   
   
    optH=uicontrol(h, ...   
        'Style','popup', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing top-2*(Nspacing+NbtnHt) width-3*Nspacing-NbtnHt NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'Nefcon I (modified)|Nefcon II|disabled',...   
        'CallBack', 'nefgui_o(''opt'')', ...   
        'Tag', 'opt');   
    helpb = uicontrol(h, ...  
        'Style', 'push', ...  
        'String', '?', ...  
    	'Units','normalized', ...  
        'Position', [left+width-Nspacing-NbtnHt top-2*(Nspacing+NbtnHt) NbtnHt NbtnHt], ...  
        'CallBack', 'hthelp(''nefcon.htm#optopt'')');  
 
   
%    sigmaH=uicontrol(h, ...   
%        'Style','slider', ...   
%    	'BackgroundColor',editColor, ...   
%        'Position', [left+Nspacing top-4*(Nspacing+NbtnHt) width-2*Nspacing NbtnHt], ...   
%    	'Units', 'normalized', ...   
%    	'Min', 0, 'Max', 1, 'Value', 0.1);   
   
    statHndl=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing top-3*(Nspacing+NbtnHt) width/3-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'learn. rate:');   
   
    rateH=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+width/3+Nspacing top-3*(Nspacing+NbtnHt) width*0.2 NbtnHt], ...   
    	'Units', 'normalized',...   
        'CallBack', 'nefgui_o(''rate'')', ...   
    	'Tag', 'rate');   
   
%    sh=uicontrol(h, ...   
%        'Style','frame', ...   
%       	'Units','normalized', ...   
%        'Position',[left+Nspacing/2 bottom+Nspacing/2 width-Nspacing 2*(Nspacing+NbtnHt)], ...   
%        'BackgroundColor',frmColor);   
    addrH=uicontrol(h, ...   
        'Style','checkbox', ...   
    	'BackgroundColor',frmColor, ...   
        'Position', [left+Nspacing top-4*(Nspacing+NbtnHt) width-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ... 
        'String', 'add rules during Optimization', ...   
        'CallBack', 'nefgui_o (''addr'')', ...   
    	'Tag','addr');   
    sH=uicontrol(h, ...   
        'Style','text', ...   
    	'BackgroundColor',frmColor, ...   
	    'HorizontalAlignment','left', ...   
        'Position', [left+Nspacing top-5*(Nspacing+NbtnHt) width/5-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'optimize:');   
    obndH=uicontrol(h, ...   
        'Style','edit', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+Nspacing+width/5 top-5*(Nspacing+NbtnHt) width/5-1*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'CallBack', 'nefgui_o (''obnd'')', ...   
    	'Tag','obnd');   
    obtH=uicontrol(h, ...   
        'Style','popup', ...   
    	'BackgroundColor',editColor, ...   
        'Position', [left+width*0.4+Nspacing top-5*(Nspacing+NbtnHt) width*0.6-2*Nspacing NbtnHt], ...   
    	'Units', 'normalized', ...   
        'String', 'time steps [s]|iteration steps|cycles',...   
        'CallBack', 'nefgui_o (''obt'')', ...   
        'Tag', 'obt');   
   
   
    % Setting global defaults - check if already set   
    nefdef;   
   
    if NEFCON_STAT == [],   
        NEFCON_STAT = 0;   
    end   
   
    % set actual values 
    nefgui_o('actualize');  
   
 elseif strcmp(action, 'close'),   
    % close current nefgui_o   
    set(handle,'visible','off');  
%    close(gcf);   
   
elseif strcmp(action, 'status'),   
    if nargin < 2,   
        p1 = '';  
    end   
   
    hndl=findobj(handle, 'Tag','status');   
    if hndl ~= [],   
        set(hndl, 'String', p1);   
    end   
   
elseif strcmp(action, 'rulelist'),   
    hndl=findobj(handle, 'Tag', 'rulelist');   
    if hndl ~= [],   
        if NEFCON_STAT == 0,   
            NEFCON_RULE = get(hndl, 'Value'); 
	if NEFCON_RULE == 1
                 NEFCON_RRATE = 1.0;
            elseif NEFCON_RULE == 2
                 NEFCON_RRATE = 0.2;
            end
            tagset(handle, 'rlr', 'String', num2str(NEFCON_RRATE));   
        else   
            disp('NEFCON: Could not change rule-learning during execution.');   
            set(hndl, 'Value', NEFCON_RULE);   
        end   
    end   
   
elseif strcmp(action, 'opt'),   
    hndl=findobj(handle, 'Tag', 'opt');   
    if hndl ~= [],   
        if NEFCON_STAT == 0,   
            NEFCON_OPT = get(hndl, 'Value');   
        else   
            nefgui_o('status', 'INFORMATION: optimization type changed.');   
            NEFCON_OPT = get(hndl, 'Value');   
%            disp('NEFCON: Could not change optimization type during execution.');   
%            set(hndl, 'Value', NEFCON_OPT);   
        end   
    end   
   
elseif strcmp(action, 'inifismat'),   
    hndl=findobj(handle, 'Tag', 'inifismat');   
    if hndl ~= [],   
        if NEFCON_STAT == 0,   
            NEFCON_IFM = get(hndl, 'String');   
        else   
            disp('NEFCON: Could not change initial fismatrix during execution.');   
            set(hndl, 'String', NEFCON_IFM);   
        end   
    end   
   
elseif strcmp(action, 'rate'),   
    hndl=findobj(handle, 'Tag', 'rate');   
    if hndl ~= [],   
        data = str2num(get(hndl, 'String'));   
        if data<0,   
            nefgui_o('status', 'ERROR: Rate must be positive.')   
            set(hndl, 'String', num2str(NEFCON_RATE));   
        else   
            NEFCON_RATE = data;   
            if NEFCON_STAT > 0,   
                nefgui_o('status', 'INFORMATION: Rate changed.');   
            end   
        end   
    end   
   
elseif strcmp(action, 'rbnd'),   
    hndl=findobj(handle, 'Tag', 'rbnd');   
    if hndl ~= [],   
        data = str2num(get(hndl, 'String'));   
        if data<0,   
            nefgui_o('status', 'ERROR: Number must be positive.')   
            set(hndl, 'String', num2str(NEFCON_RBND));   
        else   
            NEFCON_RBND = data;   
            if NEFCON_STAT > 0,   
                nefgui_o('status', 'INFORMATION: changed.');   
            end   
        end   
        nefgui('cycles', 'set');  
    end   
elseif strcmp(action, 'rbt'),   
    hndl=findobj(handle, 'Tag', 'rbt');   
    if hndl ~= [],   
        if NEFCON_STAT == 0,   
            NEFCON_RBT = get(hndl, 'Value');   
        else   
            nefgui_o('status', 'INFORMATION: units changed.');   
            NEFCON_RBT = get(hndl, 'Value');   
        end   
        nefgui('cycles', 'set');  
    end   
elseif strcmp(action, 'rbnd1'),   
    hndl=findobj(handle, 'Tag', 'rbnd1');   
    if hndl ~= [],   
        data = str2num(get(hndl, 'String'));   
        if data<0,   
            nefgui_o('status', 'ERROR: Number must be positive.')   
            set(hndl, 'String', num2str(NEFCON_RBND1));   
        else   
            NEFCON_RBND1 = data;   
            if NEFCON_STAT > 0,   
                nefgui_o('status', 'INFORMATION: changed.');   
            end   
        end   
        nefgui('cycles', 'set');  
    end   
elseif strcmp(action, 'rbt1'),   
    hndl=findobj(handle, 'Tag', 'rbt1');   
    if hndl ~= [],   
        if NEFCON_STAT == 0,   
            NEFCON_RBT1 = get(hndl, 'Value');   
        else   
            nefgui_o('status', 'INFORMATION: units changed.');   
            NEFCON_RBT1 = get(hndl, 'Value');   
        end   
        nefgui('cycles', 'set');  
    end   
   
elseif strcmp(action, 'obnd'),   
    hndl=findobj(handle, 'Tag', 'obnd');   
    if hndl ~= [],   
        data = str2num(get(hndl, 'String'));   
        if data<0,   
            nefgui_o('status', 'ERROR: Number must be positive.')   
            set(hndl, 'String', num2str(NEFCON_OBND));   
        else   
            NEFCON_OBND = data;   
            if NEFCON_STAT > 0,   
                nefgui_o('status', 'INFORMATION: changed.');   
            end   
        end   
        nefgui('cycles', 'set');  
    end   
elseif strcmp(action, 'obt'),   
    hndl=findobj(handle, 'Tag', 'obt');   
    if hndl ~= [],   
        if NEFCON_STAT == 0,   
            NEFCON_OBT = get(hndl, 'Value');   
        else   
            nefgui_o('status', 'INFORMATION: units changed.');   
            NEFCON_OBT = get(hndl, 'Value');   
%            disp('NEFCON: Could not change units during execution.');   
%            set(hndl, 'Value', NEFCON_OBT);   
        end   
        nefgui('cycles', 'set');  
    end   
 
elseif strcmp(action, 'actualize'),   
 
    % set button states 
    if NEFCON_FIS == []  
        str = 'off';  
    else  
        str = 'on';  
    end  
    tagset(handle, 'showb', 'enable', str);  
    tagset(handle, 'editb', 'enable', str);  
    tagset(handle, 'editR', 'enable', str);  
    tagset(handle, 'showS', 'enable', str);  
 
    tagset(handle, 'rulelist', 'Value', NEFCON_RULE);   
    tagset(handle, 'opt', 'Value', NEFCON_OPT);   
    tagset(handle, 'rate', 'String', num2str(NEFCON_RATE));   
    tagset(handle, 'inifismat', 'String', NEFCON_IFM);   
    tagset(handle, 'rbt', 'Value', NEFCON_RBT);   
    tagset(handle, 'rbnd', 'String', num2str(NEFCON_RBND));   
    tagset(handle, 'rbt1', 'Value', NEFCON_RBT1);   
    tagset(handle, 'rbnd1', 'String', num2str(NEFCON_RBND1));   
    tagset(handle, 'obt', 'Value', NEFCON_OBT);   
    tagset(handle, 'obnd', 'String', num2str(NEFCON_OBND));   
    tagset(handle, 'partin', 'String', num2str(NEFCON_MFIN));   
    tagset(handle, 'partout', 'String', num2str(NEFCON_MFOUT));   
    tagset(handle, 'mfit', 'Value', NEFCON_MFIT);   
    tagset(handle, 'mfot', 'Value', NEFCON_MFOT);   
    tagset(handle, 'noise', 'Value', NEFCON_GENN);   
    tagset(handle, 'addr', 'Value', NEFCON_ADDR);   
    tagset(handle, 'rlr', 'String', num2str(NEFCON_RRATE));   
    tagset(handle, 'rrm', 'String', num2str(NEFCON_RPER));   
 
elseif strcmp(action, 'partin'),   
    hndl=findobj(handle, 'Tag', 'partin');   
    if hndl ~= [],   
        data = str2num(get(hndl, 'String'));   
        if data<0 | NEFCON_STAT > 0,   
            nefgui_o('status', 'ERROR: Number must be positive or illegal status.')   
            set(hndl, 'String', num2str(NEFCON_MFIN));   
        else   
            NEFCON_MFIN = data;   
        end   
    end   
elseif strcmp(action, 'partout'),   
    hndl=findobj(handle, 'Tag', 'partout');   
    if hndl ~= [],   
        data = str2num(get(hndl, 'String'));   
        if data<0 | NEFCON_STAT > 0,   
            nefgui_o('status', 'ERROR: Number must be positive or illegal status.')   
            set(hndl, 'String', num2str(NEFCON_MFOUT));   
        else   
            NEFCON_MFOUT = data;   
        end   
    end   
 
elseif strcmp(action, 'mfit'),   
    hndl=findobj(handle, 'Tag', 'mfit');   
    if hndl ~= [],   
        if NEFCON_STAT == 0,   
            NEFCON_MFIT = get(hndl, 'Value');   
        else   
            nefgui_o('status', 'INFORMATION: units changed.');   
            NEFCON_MFIT = get(hndl, 'Value');   
        end   
    end   
 
elseif strcmp(action, 'mfot'),   
    hndl=findobj(handle, 'Tag', 'mfot');   
    if hndl ~= [],   
        if NEFCON_STAT == 0,   
            NEFCON_MFOT = get(hndl, 'Value');   
        else   
            nefgui_o('status', 'INFORMATION: units changed.');   
            NEFCON_MFOT = get(hndl, 'Value');   
        end   
    end   
 
elseif strcmp(action, 'noise'),   
    hndl=findobj(handle, 'Tag', 'noise');   
    if hndl ~= [],   
        if NEFCON_STAT ~= 0,   
            nefgui_o('status', 'INFORMATION: value changed.');   
        end   
        NEFCON_GENN = get(hndl, 'Value');   
    	if NEFCON_STAT == 2 | NEFCON_STAT == 3 
    	    NEFCON_NOISE = NEFCON_GENN; 
    	end 
    end   
 
elseif strcmp(action, 'addr'),   
    hndl=findobj(handle, 'Tag', 'addr');   
    if hndl ~= [],   
        if NEFCON_STAT ~= 0,   
            nefgui_o('status', 'INFORMATION: value changed.');   
        end   
        NEFCON_ADDR = get(hndl, 'Value');   
    end   
  
elseif strcmp(action, 'rlr'),   
    hndl=findobj(handle, 'Tag', 'rlr');   
    if hndl ~= [],   
        data = str2num(get(hndl, 'String'));   
        if data<0,   
            nefgui_o('status', 'ERROR: Rate must be positive.')   
            set(hndl, 'String', num2str(NEFCON_RRATE));   
        else   
            NEFCON_RRATE = data;   
            if NEFCON_STAT > 0,   
                nefgui_o('status', 'INFORMATION: Rate changed.');   
            end   
        end   
    end   
 
elseif strcmp(action, 'rrm'),   
    hndl=findobj(handle, 'Tag', 'rrm');   
    if hndl ~= [],   
        data = str2num(get(hndl, 'String'));   
        if data<0,   
            nefgui_o('status', 'ERROR: Rate must be positive.')   
            set(hndl, 'String', num2str(NEFCON_RPER));   
        else   
            NEFCON_RPER = data;   
            if NEFCON_STAT > 0,   
                nefgui_o('status', 'INFORMATION: Value changed.');   
            end   
        end   
    end   
 
elseif strcmp(action, ''),  
    % popup window  
    nefgui_o('actualize');  
    set(handle,'visible','on');  
    figure(handle);  
 
else   
    disp(['nefgui_o: illegal action (' action ')']);   
end   
   
